summaryrefslogtreecommitdiffstats
path: root/src/kvirc/kvs
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvirc/kvs')
-rw-r--r--src/kvirc/kvs/kvi_kvs_callbackobject.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_callbackobject.h4
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp20
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp16
-rw-r--r--src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_eventtable.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_object.cpp62
-rw-r--r--src/kvirc/kvs/kvi_kvs_object.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_object_controller.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser.cpp22
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_command.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_comment.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_dollar.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_expression.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_lside.cpp10
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_macros.h8
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp24
-rw-r--r--src/kvirc/kvs/kvi_kvs_processmanager.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_report.cpp16
-rw-r--r--src/kvirc/kvs/kvi_kvs_script.cpp12
-rw-r--r--src/kvirc/kvs/kvi_kvs_script.h14
-rw-r--r--src/kvirc/kvs/kvi_kvs_switchlist.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_treenode_operation.cpp10
-rw-r--r--src/kvirc/kvs/kvi_kvs_variant.cpp40
28 files changed, 148 insertions, 148 deletions
diff --git a/src/kvirc/kvs/kvi_kvs_callbackobject.cpp b/src/kvirc/kvs/kvi_kvs_callbackobject.cpp
index 9abb9a7..7222f05 100644
--- a/src/kvirc/kvs/kvi_kvs_callbackobject.cpp
+++ b/src/kvirc/kvs/kvi_kvs_callbackobject.cpp
@@ -55,7 +55,7 @@ KviKvsCallbackObject::~KviKvsCallbackObject()
delete m_pMagicParams;
}
-KviKvsCallbackObject::CallbackStatus KviKvsCallbackObject::execute(KviKvsVariantList * pParams,KviKvsVariant * pRetVal)
+KviKvsCallbackObject::CallbacktqStatus KviKvsCallbackObject::execute(KviKvsVariantList * pParams,KviKvsVariant * pRetVal)
{
// first of all check the window
if(!m_pTargetWindow)
diff --git a/src/kvirc/kvs/kvi_kvs_callbackobject.h b/src/kvirc/kvs/kvi_kvs_callbackobject.h
index fca4f89..c45ec1b 100644
--- a/src/kvirc/kvs/kvi_kvs_callbackobject.h
+++ b/src/kvirc/kvs/kvi_kvs_callbackobject.h
@@ -49,7 +49,7 @@ public:
// the callback is executed in another window (the associated console, if possible, otherwise the first available console)
OnlyIfWindowExists = 1
};
- enum CallbackStatus {
+ enum CallbacktqStatus {
// succesfull execution
Success,
// error in command
@@ -76,7 +76,7 @@ protected:
unsigned int m_uFlags;
protected:
// the parameter list is always shallow!
- CallbackStatus execute(KviKvsVariantList * pParams = 0,KviKvsVariant * pRetVal = 0);
+ CallbacktqStatus execute(KviKvsVariantList * pParams = 0,KviKvsVariant * pRetVal = 0);
};
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
index f376b58..0610328 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
@@ -47,7 +47,7 @@ namespace KviKvsCoreFunctions
// a_f
_REGFNC("active",active)
_REGFNC("array",array)
- _REGFNC("ascii",unicode)
+ _REGFNC("ascii",tqunicode)
_REGFNC("asciiToHex",asciiToHex)
_REGFNC("asciiToBase64",asciiToBase64)
_REGFNC("away",away)
@@ -121,7 +121,7 @@ namespace KviKvsCoreFunctions
_REGFNC("true",trueCKEYWORDWORKAROUND)
_REGFNC("typeof",typeofCKEYWORDWORKAROUND)
_REGFNC("u",u)
- _REGFNC("unicode",unicode)
+ _REGFNC("tqunicode",tqunicode)
_REGFNC("unixtime",unixtime)
_REGFNC("unserialize",unserialize)
_REGFNC("username",username)
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions.h b/src/kvirc/kvs/kvi_kvs_corefunctions.h
index b902ebe..31a73b7 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions.h
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions.h
@@ -131,7 +131,7 @@ namespace KviKvsCoreFunctions
KVSCF(trueCKEYWORDWORKAROUND);
KVSCF(typeofCKEYWORDWORKAROUND);
KVSCF(u);
- KVSCF(unicode);
+ KVSCF(tqunicode);
KVSCF(unixtime);
KVSCF(unserialize);
KVSCF(username);
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
index 096ff3c..60fbe44 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
@@ -108,7 +108,7 @@ namespace KviKvsCoreFunctions
@syntax:
<variant> $ascii(<char:string>)
@description:
- This function has been renamed to $unicode and is present
+ This function has been renamed to $tqunicode and is present
only for backward compatibility.
@seealso:
[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
@@ -489,24 +489,24 @@ namespace KviKvsCoreFunctions
@title:
$char
@short:
- Returns a character specified by unicode
+ Returns a character specified by tqunicode
@syntax:
- <string> $char(<unicode_value:integer>)
+ <string> $char(<tqunicode_value:integer>)
@description:
- Returns a character corresponding to the UNICODE code <unicode_value>.[br]
+ Returns a character corresponding to the UNICODE code <tqunicode_value>.[br]
This function can not return NUL character (UNICODE 0). Basically
you should never need it: if you do, drop me a mail.[br]
- If the <unicode_code> is not a valid UNICODE code (or is 0), this function returns
+ If the <tqunicode_code> is not a valid UNICODE code (or is 0), this function returns
an empty string.[br]
@seealso:
- [fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$unicode[/fnc]
+ [fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$tqunicode[/fnc]
*/
KVSCF(charCKEYWORDWORKAROUND)
{
kvs_uint_t ac;
KVSCF_PARAMETERS_BEGIN
- KVSCF_PARAMETER("unicode_value",KVS_PT_UINT,0,ac)
+ KVSCF_PARAMETER("tqunicode_value",KVS_PT_UINT,0,ac)
KVSCF_PARAMETERS_END
if(ac != 0 && ac < 65536)
@@ -780,15 +780,15 @@ namespace KviKvsCoreFunctions
const TQChar * c = KviTQString::nullTerminatedArray(szFormat);
if(c)
{
- while(c->unicode())
+ while(c->tqunicode())
{
//Check for right Characters
#ifdef COMPILE_ON_WINDOWS
- if (szAllowedCharacters.find((char)(c->unicode()),0,true) >= 0) tmpFormat += '%';
+ if (szAllowedCharacters.find((char)(c->tqunicode()),0,true) >= 0) tmpFormat += '%';
#else
if (c->isLetter()) tmpFormat += '%';
#endif
- tmpFormat += (char)(c->unicode());
+ tmpFormat += (char)(c->tqunicode());
c++;
}
}
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
index e56abbe..a5478dc 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
@@ -401,12 +401,12 @@ namespace KviKvsCoreFunctions
if(szLongSwitch.isEmpty())
v = sl->find(szSwitch);
else
- v = sl->find(szSwitch[0].unicode(),szLongSwitch);
+ v = sl->find(szSwitch[0].tqunicode(),szLongSwitch);
}else {
if(szLongSwitch.isEmpty())
v = sl->find(szSwitch[0]);
else
- v = sl->find(szSwitch[0].unicode(),szLongSwitch);
+ v = sl->find(szSwitch[0].tqunicode(),szLongSwitch);
}
if(v)KVSCF_pRetBuffer->copyFrom(*v);
@@ -842,15 +842,15 @@ namespace KviKvsCoreFunctions
/////////////////////////////////////////////////////////////////////////////////////////
/*
- @doc: unicode
+ @doc: tqunicode
@type:
function
@title:
- $unicode
+ $tqunicode
@short:
Returns the UNICODE code of a sets of characters
@syntax:
- <variant> $unicode(<char:string>)
+ <variant> $tqunicode(<char:string>)
@description:
If <char> is composed only of a single character
then returns its UNICODE code point as an integer.
@@ -860,7 +860,7 @@ namespace KviKvsCoreFunctions
[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
*/
- KVSCF(unicode)
+ KVSCF(tqunicode)
{
TQString sz;
KVSCF_PARAMETERS_BEGIN
@@ -871,10 +871,10 @@ namespace KviKvsCoreFunctions
{
KviKvsArray * a = new KviKvsArray();
for(kvs_int_t i=0;i<sz.length();i++)
- a->set(i,new KviKvsVariant((kvs_int_t)(sz[(int)i].unicode())));
+ a->set(i,new KviKvsVariant((kvs_int_t)(sz[(int)i].tqunicode())));
KVSCF_pRetBuffer->setArray(a);
} else {
- KVSCF_pRetBuffer->setInteger((kvs_int_t)(sz[0].unicode()));
+ KVSCF_pRetBuffer->setInteger((kvs_int_t)(sz[0].tqunicode()));
}
return true;
}
diff --git a/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp b/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
index 85c6c5c..acf8eec 100644
--- a/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
+++ b/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
@@ -673,7 +673,7 @@ namespace KviKvsCoreSimpleCommands
to load catalogues that reside in different directories.[br]
[b]NOTE[/b][br]
This feature is currently work in progress: the scripting engine
- is not yet fully unicode and thus some more exotic translations may still suffer...
+ is not yet fully tqunicode and thus some more exotic translations may still suffer...
@seealso:
[fnc]$tr[/fnc], [cmd]trunload[/cmd]
*/
diff --git a/src/kvirc/kvs/kvi_kvs_eventtable.cpp b/src/kvirc/kvs/kvi_kvs_eventtable.cpp
index b2fc61b..55c086d 100644
--- a/src/kvirc/kvs/kvi_kvs_eventtable.cpp
+++ b/src/kvirc/kvs/kvi_kvs_eventtable.cpp
@@ -254,7 +254,7 @@ KviKvsEvent KviKvsEventManager::m_appEventTable[KVI_NUM_SCRIPT_EVENTS]=
@description:
This event is triggered in the first console of a new frame window.
A frame window is the toplevel window that contains the consoles
- and the other MDI children windows.
+ and the other MDI tqchildren windows.
@seealso:
[event:onframewindowdestroyed]OnFrameWindowDestroyed[/event]
*/
diff --git a/src/kvirc/kvs/kvi_kvs_object.h b/src/kvirc/kvs/kvi_kvs_object.h
index f59c098..a19bd5f 100644
--- a/src/kvirc/kvs/kvi_kvs_object.h
+++ b/src/kvirc/kvs/kvi_kvs_object.h
@@ -164,7 +164,7 @@ protected:
bool function_findChild(KviKvsObjectFunctionCall *c);
bool function_childCount(KviKvsObjectFunctionCall *c);
bool function_emit(KviKvsObjectFunctionCall *c);
- bool function_children(KviKvsObjectFunctionCall *c);
+ bool function_tqchildren(KviKvsObjectFunctionCall *c);
bool function_signalSender(KviKvsObjectFunctionCall *c);
bool function_signalName(KviKvsObjectFunctionCall *c);
bool function_destructor(KviKvsObjectFunctionCall *c);
diff --git a/src/kvirc/kvs/kvi_kvs_object_controller.cpp b/src/kvirc/kvs/kvi_kvs_object_controller.cpp
index 4739f33..b2c1c8b 100644
--- a/src/kvirc/kvs/kvi_kvs_object_controller.cpp
+++ b/src/kvirc/kvs/kvi_kvs_object_controller.cpp
@@ -73,7 +73,7 @@ void KviKvsObjectController::init()
m_pObjectClass->registerFunctionHandler("findChild",KVI_PTR2MEMBER(KviKvsObject::function_findChild));
m_pObjectClass->registerFunctionHandler("childCount",KVI_PTR2MEMBER(KviKvsObject::function_childCount));
m_pObjectClass->registerFunctionHandler("emit",KVI_PTR2MEMBER(KviKvsObject::function_emit));
- m_pObjectClass->registerFunctionHandler("children",KVI_PTR2MEMBER(KviKvsObject::function_children));
+ m_pObjectClass->registerFunctionHandler("tqchildren",KVI_PTR2MEMBER(KviKvsObject::function_tqchildren));
m_pObjectClass->registerFunctionHandler("signalSender",KVI_PTR2MEMBER(KviKvsObject::function_signalSender));
m_pObjectClass->registerFunctionHandler("signalName",KVI_PTR2MEMBER(KviKvsObject::function_signalName));
m_pObjectClass->registerFunctionHandler("destructor",KVI_PTR2MEMBER(KviKvsObject::function_destructor));
diff --git a/src/kvirc/kvs/kvi_kvs_parser.cpp b/src/kvirc/kvs/kvi_kvs_parser.cpp
index 074753e..fc483f5 100644
--- a/src/kvirc/kvs/kvi_kvs_parser.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser.cpp
@@ -117,9 +117,9 @@ void KviKvsParser::report(bool bError,const TQChar * pLocation,const TQString &s
void KviKvsParser::errorBadChar(const TQChar * pLocation,char cExpected,const char * szCommandName)
{
- if(pLocation->unicode())
- error(pLocation,__tr2qs("Found character '%q' (unicode 0x%x) where '%c' was expected: see \"/help %s\" for the command syntax"),
- pLocation,pLocation->unicode(),cExpected,szCommandName);
+ if(pLocation->tqunicode())
+ error(pLocation,__tr2qs("Found character '%q' (tqunicode 0x%x) where '%c' was expected: see \"/help %s\" for the command syntax"),
+ pLocation,pLocation->tqunicode(),cExpected,szCommandName);
else
error(pLocation,__tr2qs("Found end of input where character '%c' was expected: see \"/help %s\" for the command syntax"),
cExpected,szCommandName);
@@ -1349,7 +1349,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
so the callback code is empty, but if you continue reading we will soon fill it.
[/p]
- [big]A typical addon layout[/big]
+ [big]A typical addon tqlayout[/big]
[p]
As stated above, the addons are usually shipped in a compressed archive.
Once uncompressed, the archive will expand into a small directory tree
@@ -1400,7 +1400,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
[/p]
[p]
The entries in [b]bold[/b] are directories while the other are files.
- Please note that this is a general layout for a huge and rather complex
+ Please note that this is a general tqlayout for a huge and rather complex
addon: you might not need all of these directories. Remember: the minimal
addon has only an install.kvs file. Anyway, a really cool addon
will probably have all of them and maybe some more.
@@ -1496,7 +1496,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
[p]
It is a good idea to start on the KVIrc web site. There are surely
several addons to look at. Pick one that seems simple and analyze its
- layout and code (wow... the free software!). It will be easier to do than it was to explain it :D
+ tqlayout and code (wow... the free software!). It will be easier to do than it was to explain it :D
[/p]
[p]
Have fun! :)
@@ -2724,7 +2724,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseInstruction()
return parseCommand();
} else {
// what the heck is this ?
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where an instruction was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where an instruction was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
break;
@@ -2839,7 +2839,7 @@ KviKvsTreeNodeSwitchList * KviKvsParser::parseCommandSwitchList()
if(KVSP_curCharUnicode == 0)
{
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a switch dash"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a switch dash"),KVSP_curCharPointer,KVSP_curCharUnicode);
} else {
error(KVSP_curCharPointer,__tr2qs("Unexpected end of script after a switch dash"));
}
@@ -2880,12 +2880,12 @@ KviKvsTreeNodeSwitchList * KviKvsParser::parseCommandSwitchList()
if(bLong)
sw->addLong(TQString(pSw,pSwEnd - pSw),p);
else
- sw->addShort(pSw->lower().unicode(),p);
+ sw->addShort(pSw->lower().tqunicode(),p);
} else {
if(bLong)
sw->addLong(TQString(pSw,pSwEnd - pSw),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
else
- sw->addShort(pSw->lower().unicode(),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
+ sw->addShort(pSw->lower().tqunicode(),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
}
}
@@ -3300,7 +3300,7 @@ KviKvsTreeNodeData * KviKvsParser::parseArrayIndex()
error(KVSP_curCharPointer,__tr2qs("Unexpected end of line in array index (missing ']' character or unescaped newline)"));
break;
default:
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) in array index: it should be already terminated"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) in array index: it should be already terminated"),KVSP_curCharPointer,KVSP_curCharUnicode);
break;
}
return 0;
diff --git a/src/kvirc/kvs/kvi_kvs_parser_command.cpp b/src/kvirc/kvs/kvi_kvs_parser_command.cpp
index 865bf18..094fc30 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_command.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_command.cpp
@@ -139,7 +139,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseCommand()
// perl.begin has a *really* half special parsing routine
if(iIdentifierLen == 4)
{
- if(pIdentifier->lower().unicode() == 'p')
+ if(pIdentifier->lower().tqunicode() == 'p')
{
if(KviTQString::equalCI(szIdentifier,"perl"))
{
diff --git a/src/kvirc/kvs/kvi_kvs_parser_comment.cpp b/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
index ea15840..18fbbbe 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
@@ -85,7 +85,7 @@ KviKvsTreeNode * KviKvsParser::parseComment()
}
break;
default:
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a slash (it is a typo or a malformed comment begin ?)"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a slash (it is a typo or a malformed comment begin ?)"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
break;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp b/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
index b556614..a2d6516 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
@@ -50,7 +50,7 @@ KviKvsTreeNodeData * KviKvsParser::parseDollar(bool bInObjScope)
if(!KVSP_curCharIsFunctionStart)
{
if(KVSP_curCharUnicode == 0)warning(KVSP_curCharPointer,__tr2qs("Unexpected end of script after '$' function call prefix"));
- else warning(KVSP_curCharPointer,__tr2qs("Unexpected character %q (unicode %x) after '$' function call prefix"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ else warning(KVSP_curCharPointer,__tr2qs("Unexpected character %q (tqunicode %x) after '$' function call prefix"),KVSP_curCharPointer,KVSP_curCharUnicode);
error(KVSP_curCharPointer,__tr2qs("Syntax error after '$' function call prefix. If you want to use a plain '$' in the code you need to escape it"));
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_expression.cpp b/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
index 44ce71d..ee91df4 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
@@ -420,7 +420,7 @@ KviKvsTreeNodeExpression * KviKvsParser::parseExpressionOperandCore(char termina
pDataList->append(new KviKvsTreeNodeConstantData(pBegin,new KviKvsVariant(iVal)));
} else {
// bOk is false
- if(pBegin->unicode() == '0')
+ if(pBegin->tqunicode() == '0')
{
if(tmp.length() > 2)
{
@@ -448,7 +448,7 @@ KviKvsTreeNodeExpression * KviKvsParser::parseExpressionOperandCore(char termina
}
}
} else {
- error(KVSP_curCharPointer,__tr2qs("Unexpected character %q (unicode %h) in expression. If it meant to be a string use the quotes."),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character %q (tqunicode %h) in expression. If it meant to be a string use the quotes."),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pDataList;
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_lside.cpp b/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
index bcca75d..3733f55 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
@@ -828,7 +828,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -846,7 +846,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pFirst;
return 0;
}
@@ -869,7 +869,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pFirst;
return 0;
}
@@ -1173,10 +1173,10 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseVoidFunctionCallOrOperation()
// must be followed by the end of a command
if(r->isFunctionCall())
{
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a void function call: end of instruction expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a void function call: end of instruction expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
} else {
warning(pBegin,__tr2qs("Unexpected (and senseless) read-only data evaluation"));
- warning(pBegin,__tr2qs("Unexpected character '%q' (unicode %x)"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ warning(pBegin,__tr2qs("Unexpected character '%q' (tqunicode %x)"),KVSP_curCharPointer,KVSP_curCharUnicode);
error(KVSP_curCharPointer,__tr2qs("Syntax error: confused by earlier errors: bailing out"));
}
delete r;
diff --git a/src/kvirc/kvs/kvi_kvs_parser_macros.h b/src/kvirc/kvs/kvi_kvs_parser_macros.h
index 8de1f47..e727e4a 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_macros.h
+++ b/src/kvirc/kvs/kvi_kvs_parser_macros.h
@@ -29,15 +29,15 @@
#define KVSP_backChar m_ptr--
#define KVSP_backNChars(n) m_ptr -= n
-#define KVSP_curCharUnicode (m_ptr->unicode())
+#define KVSP_curCharUnicode (m_ptr->tqunicode())
#define KVSP_curCharPointer m_ptr
#define KVSP_curCharIsLetter (m_ptr->isLetter())
#define KVSP_curCharIsNumber (m_ptr->isNumber())
#define KVSP_curCharIsLetterOrNumber (m_ptr->isLetterOrNumber())
-#define KVSP_curCharIsFunctionStart (m_ptr->isLetterOrNumber() || (m_ptr->unicode() == '(') || (m_ptr->unicode() == '{') || (m_ptr->unicode() == '$'))
-#define KVSP_curCharIsEndOfCommand ((m_ptr->unicode() == ';') || (m_ptr->unicode() == 0) || (m_ptr->unicode() == '\n') || (m_ptr->unicode() == '\r'))
-#define KVSP_curCharIsEndOfBuffer (m_ptr->unicode() == 0)
+#define KVSP_curCharIsFunctionStart (m_ptr->isLetterOrNumber() || (m_ptr->tqunicode() == '(') || (m_ptr->tqunicode() == '{') || (m_ptr->tqunicode() == '$'))
+#define KVSP_curCharIsEndOfCommand ((m_ptr->tqunicode() == ';') || (m_ptr->tqunicode() == 0) || (m_ptr->tqunicode() == '\n') || (m_ptr->tqunicode() == '\r'))
+#define KVSP_curCharIsEndOfBuffer (m_ptr->tqunicode() == 0)
#define KVSP_setCurCharPointer(_ptr) m_ptr = _ptr
diff --git a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
index 6d6ab96..95eca6a 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
@@ -207,7 +207,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandUnset()
if(!KVSP_curCharIsEndOfCommand)
{
warning(KVSP_curCharPointer,__tr2qs("The 'unset' command needs a variable list"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -277,7 +277,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandGlobal()
if(!KVSP_curCharIsEndOfCommand)
{
warning(KVSP_curCharPointer,__tr2qs("The 'global' command needs a variable list"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -376,7 +376,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharUnicode != '(')
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -443,7 +443,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -471,7 +471,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -498,7 +498,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -628,7 +628,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandWhile()
if(KVSP_curCharUnicode != '(')
{
warning(KVSP_curCharPointer,__tr2qs("The while command needs an expression enclosed in parenthesis"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -740,7 +740,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandDo()
if(KVSP_curCharIsEndOfBuffer)
error(KVSP_curCharPointer,__tr2qs("Unexpected end of command after the 'do' command block: expected 'while' keyword"));
else
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'while' keyword was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'while' keyword was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
if(i)delete i;
return 0;
}
@@ -1089,7 +1089,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandFor()
if(KVSP_curCharUnicode != ')')
{
- error(KVSP_curCharPointer,__tr2qs("Found char %q (unicode %x) while looking for the terminating ')' in 'for' command"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found char %q (tqunicode %x) while looking for the terminating ')' in 'for' command"),KVSP_curCharPointer,KVSP_curCharUnicode);
if(i1)delete i1;
if(e)delete e;
if(i2)delete i2;
@@ -1193,7 +1193,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandForeach()
if((KVSP_curCharUnicode != '%') && (KVSP_curCharUnicode != '$') && (KVSP_curCharUnicode != '@'))
{
warning(KVSP_curCharPointer,__tr2qs("The 'foreach' command expects a writeable iteration variable as first parameter"));
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where '%' or '$' was expected: see /help foreach for the command syntax"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where '%' or '$' was expected: see /help foreach for the command syntax"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -1419,7 +1419,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandSwitch()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'case','match','regexp','default' or 'break' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'case','match','regexp','default' or 'break' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pSwitch;
return 0;
}
@@ -1566,7 +1566,7 @@ KviKvsTreeNodeSpecialCommandDefpopupLabelPopup * KviKvsParser::parseSpecialComma
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'prologue','separator','label','popup','item','extpopup' or 'epilogue' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'prologue','separator','label','popup','item','extpopup' or 'epilogue' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pPopup;
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_processmanager.cpp b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
index 3748877..a7aeacb 100644
--- a/src/kvirc/kvs/kvi_kvs_processmanager.cpp
+++ b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
@@ -73,7 +73,7 @@ bool KviKvsProcessAsyncOperation::start()
if(szShell.isEmpty())
{
#ifdef COMPILE_ON_WINDOWS
- // [01:26:00] <PragmaOff> btw, what is qt_winunicode ?
+ // [01:26:00] <PragmaOff> btw, what is qt_wintqunicode ?
// [01:26:12] <kode54> TQt export specific to win32
// [01:26:27] <kode54> bool which indicates whether system is Unicode (NT) or not
// [01:26:58] <kode54> not sure if that's documented, but it is a public export
@@ -330,7 +330,7 @@ void KviKvsProcessAsyncOperation::processExited()
if(m_pData->iFlags & KVI_KVS_PROCESSDESCRIPTOR_TRIGGERTERMINATED)
{
TQString szRetVal;
- szRetVal.setNum(m_pProcess->exiStatus());
+ szRetVal.setNum(m_pProcess->exitqStatus());
trigger(EventTerminated,szRetVal);
}
diff --git a/src/kvirc/kvs/kvi_kvs_report.cpp b/src/kvirc/kvs/kvi_kvs_report.cpp
index 7618e29..aa40ef3 100644
--- a/src/kvirc/kvs/kvi_kvs_report.cpp
+++ b/src/kvirc/kvs/kvi_kvs_report.cpp
@@ -60,7 +60,7 @@ void KviKvsReport::findLineAndCol(const TQChar * pBegin,const TQChar * pPoint,in
const TQChar * pPrevLine = 0;
const TQChar * pLineBegin = pBegin;
- unsigned short us = pBegin->unicode();
+ unsigned short us = pBegin->tqunicode();
while(us && (pBegin < pPoint))
{
@@ -73,7 +73,7 @@ void KviKvsReport::findLineAndCol(const TQChar * pBegin,const TQChar * pPoint,in
} else {
pBegin++;
}
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
}
iCol = (pBegin - pLineBegin) + 1;
@@ -92,7 +92,7 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
const TQChar * pPrevLine = 0;
const TQChar * pLineBegin = pBegin;
- unsigned short us = pBegin->unicode();
+ unsigned short us = pBegin->tqunicode();
while(us && (pBegin < pPoint))
{
@@ -105,7 +105,7 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
} else {
pBegin++;
}
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
}
iCol = (pBegin - pLineBegin) + 1;
@@ -131,11 +131,11 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
// current line
pBegin = pLineBegin;
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
while(us && (us != '\n'))
{
pBegin++;
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
}
if(us)pBegin++;
@@ -152,11 +152,11 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
// next line
pLineBegin = pBegin;
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
while(us && (us != '\n'))
{
pBegin++;
- us = pBegin->unicode();
+ us = pBegin->tqunicode();
}
if(us)pBegin++;
diff --git a/src/kvirc/kvs/kvi_kvs_script.cpp b/src/kvirc/kvs/kvi_kvs_script.cpp
index d77919d..c9c4f4f 100644
--- a/src/kvirc/kvs/kvi_kvs_script.cpp
+++ b/src/kvirc/kvs/kvi_kvs_script.cpp
@@ -293,22 +293,22 @@ int KviKvsScript::executeInternal(KviKvsRunTimeContext * pContext)
// lock this script
m_pData->m_uLock++;
- int iRunStatus = Success;
+ int iRuntqStatus = Success;
if(!m_pData->m_pTree->execute(pContext))
{
- if(pContext->error())iRunStatus = Error;
+ if(pContext->error())iRuntqStatus = Error;
else {
// else just a halt, return or sth like that
if(pContext->haltCalled())
- iRunStatus |= HaltEncountered;
+ iRuntqStatus |= HaltEncountered;
}
}
// we can't block any longer: unlock
m_pData->m_uLock--;
- return iRunStatus;
+ return iRuntqStatus;
}
int KviKvsScript::execute(KviWindow * pWnd,KviKvsVariantList * pParams,KviKvsVariant * pRetVal,int iRunFlags,KviKvsExtendedRunTimeData * pExtData)
@@ -343,13 +343,13 @@ int KviKvsScript::execute(KviWindow * pWnd,KviKvsVariantList * pParams,KviKvsVar
if(iRunFlags & Quiet)
ctx.disableReporting();
- int iRunStatus = executeInternal(&ctx);
+ int iRuntqStatus = executeInternal(&ctx);
// don't forget to delete the params
if(bDeleteParams)delete pParams;
if(bDeleteRetVal)delete pRetVal;
pParams = 0; pRetVal = 0;
- return iRunStatus;
+ return iRuntqStatus;
}
diff --git a/src/kvirc/kvs/kvi_kvs_switchlist.h b/src/kvirc/kvs/kvi_kvs_switchlist.h
index fc31461..b82d93f 100644
--- a/src/kvirc/kvs/kvi_kvs_switchlist.h
+++ b/src/kvirc/kvs/kvi_kvs_switchlist.h
@@ -48,7 +48,7 @@ public:
KviKvsVariant * find(const TQChar &c)
{
- return m_pShortSwitchDict ? m_pShortSwitchDict->find(c.unicode()) : 0;
+ return m_pShortSwitchDict ? m_pShortSwitchDict->find(c.tqunicode()) : 0;
};
KviKvsVariant * find(unsigned short uShortKey)
diff --git a/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp b/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
index 42338ae..c303ceb 100644
--- a/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
+++ b/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp
@@ -34,7 +34,7 @@ KviKvsTreeNodeCompositeData::KviKvsTreeNodeCompositeData(const TQChar * pLocatio
: KviKvsTreeNodeData(pLocation)
{
#ifdef DEBUGME
- if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two children!");
+ if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two tqchildren!");
#endif
m_pSubData = pSubData;
m_pSubData->setAutoDelete(true);
diff --git a/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp b/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
index bdb1310..26b05b9 100644
--- a/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
+++ b/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
@@ -1467,18 +1467,18 @@ bool KviKvsTreeNodeOperationStringSubstitution::execute(KviKvsRunTimeContext * c
TQString szReplaced;
const TQChar * p2 = KviTQString::nullTerminatedArray(szR);
const TQChar * begin = p2;
- while(p2->unicode())
+ while(p2->tqunicode())
{
- if(p2->unicode() == '\\')
+ if(p2->tqunicode() == '\\')
{
p2++;
- if(p2->unicode() >= '0' && p2->unicode() <= '9')
+ if(p2->tqunicode() >= '0' && p2->tqunicode() <= '9')
{
szReplaced.append(TQString(begin,(p2 - begin) - 1));
- szReplaced.append(re.cap(p2->unicode() - '0'));
+ szReplaced.append(re.cap(p2->tqunicode() - '0'));
p2++;
begin = p2;
- } else if(p2->unicode())p2++;
+ } else if(p2->tqunicode())p2++;
} else p2++;
}
if(begin != p2)szReplaced.append(TQString(begin,p2 - begin));
diff --git a/src/kvirc/kvs/kvi_kvs_variant.cpp b/src/kvirc/kvs/kvi_kvs_variant.cpp
index b2da370..c4e457f 100644
--- a/src/kvirc/kvs/kvi_kvs_variant.cpp
+++ b/src/kvirc/kvs/kvi_kvs_variant.cpp
@@ -1010,7 +1010,7 @@ KviKvsVariant* KviKvsVariant::unserializeNull(const TQChar** aux)
KviKvsVariant* KviKvsVariant::unserializeRealOrInteger(const TQChar** aux)
{
TQString data;
- if((*aux)->unicode() == '-')
+ if((*aux)->tqunicode() == '-')
{
data.append('-');
(*aux)++;
@@ -1024,7 +1024,7 @@ KviKvsVariant* KviKvsVariant::unserializeRealOrInteger(const TQChar** aux)
data.append(**aux);
(*aux)++;
}
- if((*aux)->unicode()=='.')
+ if((*aux)->tqunicode()=='.')
{
return unserializeReal(aux,data);
}
@@ -1042,15 +1042,15 @@ KviKvsVariant* KviKvsVariant::unserializeReal(const TQChar** aux,TQString& data)
(*aux)++;
}
- if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
+ if((*aux)->tqunicode() == 'e' || (*aux)->tqunicode() == 'E')
{
(*aux)++;
- if((*aux)->unicode() == '-')
+ if((*aux)->tqunicode() == '-')
{
exponent.append('-');
(*aux)++;
} else {
- if((*aux)->unicode() == '+')
+ if((*aux)->tqunicode() == '+')
{
exponent.append('+');
(*aux)++;
@@ -1079,15 +1079,15 @@ KviKvsVariant* KviKvsVariant::unserializeInteger(const TQChar** aux,TQString& da
TQString exponent;
- if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
+ if((*aux)->tqunicode() == 'e' || (*aux)->tqunicode() == 'E')
{
(*aux)++;
- if((*aux)->unicode() == '-')
+ if((*aux)->tqunicode() == '-')
{
exponent.append('-');
(*aux)++;
} else {
- if((*aux)->unicode() == '+')
+ if((*aux)->tqunicode() == '+')
{
exponent.append('+');
(*aux)++;
@@ -1122,9 +1122,9 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
TQString hex; //temp var
//skip leading "
(*aux)++;
- while((*aux)->unicode())
+ while((*aux)->tqunicode())
{
- switch((*aux)->unicode())
+ switch((*aux)->tqunicode())
{
case '"':
//EOF
@@ -1134,7 +1134,7 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
case '\\':
//Special
(*aux)++;
- switch((*aux)->unicode())
+ switch((*aux)->tqunicode())
{
case 't':
data.append('\t');
@@ -1159,11 +1159,11 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
//4 hexadecmical digits pending...
hex="";
(*aux)++;
- for(int k=0;k<4 && (*aux)->unicode(); k++)
+ for(int k=0;k<4 && (*aux)->tqunicode(); k++)
{
if((*aux)->isDigit() ||
- ((*aux)->unicode() >='A' && (*aux)->unicode() <='F')|| //ABCDEF
- ((*aux)->unicode() >='a' && (*aux)->unicode() <='f')) //abcdef
+ ((*aux)->tqunicode() >='A' && (*aux)->tqunicode() <='F')|| //ABCDEF
+ ((*aux)->tqunicode() >='a' && (*aux)->tqunicode() <='f')) //abcdef
{
hex.append(**aux);
(*aux)++;
@@ -1203,7 +1203,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
//waiting for starting of string
- if((*aux)->unicode()!='\"')
+ if((*aux)->tqunicode()!='\"')
{
//strange characters
delete pHash;
@@ -1221,7 +1221,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
//waiting for name-value delimeter
- if((*aux)->unicode()!=':')
+ if((*aux)->tqunicode()!=':')
{
//strange characters
delete pHash;
@@ -1238,7 +1238,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
i++;
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->unicode())
+ switch((*aux)->tqunicode())
{
case ',':
//goto next
@@ -1278,7 +1278,7 @@ KviKvsVariant* KviKvsVariant::unserializeArray(const TQChar** aux)
i++;
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->unicode())
+ switch((*aux)->tqunicode())
{
case ',':
//goto next
@@ -1310,7 +1310,7 @@ KviKvsVariant* KviKvsVariant::unserialize(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->unicode())
+ switch((*aux)->tqunicode())
{
case 't':
//true
@@ -1373,7 +1373,7 @@ KviKvsVariant* KviKvsVariant::unserialize(const TQString& data)
pResult = unserialize(&aux);
- if(aux->unicode())
+ if(aux->tqunicode())
{
//strange extra characters?
if(pResult) delete pResult;
diff --git a/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp b/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
index 4f11db0..0a4aa54 100644
--- a/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
+++ b/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
@@ -427,7 +427,7 @@ namespace KviKvsCoreSimpleCommands
// TQChar o = tbOp.length() > 0 ? tbOp[0] : TQChar('x');
- switch(o.unicode())
+ switch(o.tqunicode())
{
case 't':
KviTalToolTip::remove(pButton);
@@ -853,7 +853,7 @@ namespace KviKvsCoreSimpleCommands
{
TQString szWnd;
v->asString(szWnd);
//#warning "FIXME: the window database is not unicode! (we even could keep integer window id's at this point!)"
pWnd = g_pApp->findWindow(szWnd.utf8().data());
if(!pWnd)
{
@@ -853,7 +853,7 @@ namespace KviKvsCoreSimpleCommands
TQString szWnd;
v->asString(szWnd);
- //#warning "FIXME: the window database is not unicode! (we even could keep integer window id's at this point!)"
+ //#warning "FIXME: the window database is not tqunicode! (we even could keep integer window id's at this point!)"
pWnd = g_pApp->findWindow(szWnd.utf8().data());
if(!pWnd)
diff --git a/src/kvirc/kvs/kvi_kvs_object.cpp b/src/kvirc/kvs/kvi_kvs_object.cpp
index e5ff0a5..677095d 100644
--- a/src/kvirc/kvs/kvi_kvs_object.cpp
+++ b/src/kvirc/kvs/kvi_kvs_object.cpp
@@ -69,11 +69,11 @@
[big]Basic concepts[/big]
Objects are arranged in tree structures.
- Each object that you create is either toplevel object or a children
+ Each object that you create is either toplevel object or a tqchildren
of another object. A toplevel object is a parentless one.
- Obviously all objects can have children objects.[br][br]
+ Obviously all objects can have tqchildren objects.[br][br]
- When an object is destroyed , all its children are also destroyed.
+ When an object is destroyed , all its tqchildren are also destroyed.
The toplevel objects are automatically destroyed when KVIrc quits.
The objects are global to the entire application (this is different
from previous KVIrc releases where the objects were local
@@ -121,7 +121,7 @@
[example]
[cmd]delete[/cmd] %myobject
[/example]
- If the destroyed object has children objects , these are destroyed too.[br][br]
+ If the destroyed object has tqchildren objects , these are destroyed too.[br][br]
[big]Fields : objects as pseudo-structures[/big]
@@ -196,15 +196,15 @@
[cmd]delete[/cmd] %tmp
[/example]
Another cool function exported by the [class:object]object[/class] class is the
- [classfnc:object]$children[/classfnc]() function.
- It returns a comma separated list of children identifiers.[br]
+ [classfnc:object]$tqchildren[/classfnc]() function.
+ It returns a comma separated list of tqchildren identifiers.[br]
[example]
%tmp = [fnc]$new[/fnc]([class]object[/class],0,myobject)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child1)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child2)
%tmpchild = [fnc]$new[/fnc]([class]object[/class],%tmp,child3)
- [cmd]echo[/cmd] The object's children list is : %tmp->[classfnc:object]$children[/classfnc]()
- # Destroy the object and the children
+ [cmd]echo[/cmd] The object's tqchildren list is : %tmp->[classfnc:object]$tqchildren[/classfnc]()
+ # Destroy the object and the tqchildren
[cmd]delete[/cmd] %tmp
[/example]
There are two special functions for each objects: the "constructor" and the "destructor".
@@ -230,25 +230,25 @@
[cmd]privateimpl[/cmd](%tmp,destructor)
{
%count = 0;
- [cmd]foreach[/cmd](%t,[fnc]$this[/fnc]-&gt;[classfnc:object]$children[/classfnc]())
+ [cmd]foreach[/cmd](%t,[fnc]$this[/fnc]-&gt;[classfnc:object]$tqchildren[/classfnc]())
{
[cmd]echo[/cmd] Children : %t-&gt;[classfnc:object]$name[/classfnc]() with class %t-&gt;[classfnc:object]$class[/classfnc]()
%count++
}
- [cmd]echo[/cmd] Just before destroying my %count children.
+ [cmd]echo[/cmd] Just before destroying my %count tqchildren.
}
# Destroy the object and the children
[cmd]delete[/cmd] %tmp
[/example]
In the example above four objects have been created.
- A "parent" object named "myobject" , and three children objects.
+ A "parent" object named "myobject" , and three tqchildren objects.
The destructor has been reimplemented for each child object,
to make it "say" its name (Please note the usage of [fnc]$this[/fnc]).
- In the parent destructor the children have been counted and listed.[br]
+ In the parent destructor the tqchildren have been counted and listed.[br]
Then the parent object is destroyed causing to:[br]
- trigger the parent destructor.[br]
- - destroy all the children (and conseguently trigger all the "individual" destructors).[br][br]
+ - destroy all the tqchildren (and conseguently trigger all the "individual" destructors).[br][br]
Not all the object functions must return a value:
If a function does not return a meaningful value , or you just want to ignore it , you can call it in the following way:[br]
@@ -339,7 +339,7 @@
The above class is named "helloworld". It inherits the [class]object[/class] class.
This means that it acquires all the [class]object[/class] fuunctions: [classfnc:object]$name[/classfnc]() ,
- [classfnc:object]$class[/class]() , [classfnc:object]$children[/classfnc]()...
+ [classfnc:object]$class[/class]() , [classfnc:object]$tqchildren[/classfnc]()...
Additionally , it has the $sayhello() function, that "echoes Hello world" to the console.
Now you can create an instance of this class:
[example]
@@ -486,7 +486,7 @@
@description:
This is the base class for all the builtin KVirc object classes.
It exports the functions to retrieve the object name, to iterate
- through children objects and to lookup a child object by name or class.
+ through tqchildren objects and to lookup a child object by name or class.
Additionally , this class provides the builtin timer functionality.
The [classfnc]$constructor[/classfnc] and [classfnc]$destructor[/classfnc]
functions are empty implementations that all the other classes inherit.
@@ -521,15 +521,15 @@
Returns the first child that matches <class> and <name>.
If <class> is an empty string, any class matches,
if <name> is an empty string, any name matches.
- This function traverses the entire tree of children
+ This function traverses the entire tree of tqchildren
but is NOT recursive.
!fn: $childCount()
- Returns the number of children objects
+ Returns the number of tqchildren objects
!fn: $emit(<signal_name>[,parameters])
Emits the signal <signal_name> passing the optional [parameters].
See the [doc:objects]objects documentation[/doc] for an overview of signals and slots.
- !fn: $children()
- Returns an array of children object identifiers.
+ !fn: $tqchildren()
+ Returns an array of tqchildren object identifiers.
!fn: $signalSender()
Returns the current signal sender when in a slot connected to a signal.
In other contexts this function returns an empty string.
@@ -955,7 +955,7 @@ bool KviKvsObject::function_destructor(KviKvsObjectFunctionCall * c)
return true;
}
-bool KviKvsObject::function_children(KviKvsObjectFunctionCall * c)
+bool KviKvsObject::function_tqchildren(KviKvsObjectFunctionCall * c)
{
KviKvsArray * a = new KviKvsArray();
int id=0;
@@ -1042,7 +1042,7 @@ bool KviKvsObject::function_listProperties(KviKvsObjectFunctionCall * c)
kvs_int_t cnt = 0;
if(m_pObject)
{
- const TQMetaObject *o = m_pObject->metaObject();
+ const TQMetaObject *o = m_pObject->tqmetaObject();
if(!bArray)
w->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs("Properties for TQt class %s"),o->className());
#ifndef COMPILE_USE_QT4
@@ -1120,7 +1120,7 @@ bool KviKvsObject::function_listProperties(KviKvsObjectFunctionCall * c)
cnt++;
}
#ifndef COMPILE_USE_QT4
- o = o->superClass();
+ o = o->tqsuperClass();
}
#endif
@@ -1154,9 +1154,9 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
}
#ifdef COMPILE_USE_QT4
- int idx = m_pObject->metaObject()->indexOfProperty(szName);
+ int idx = m_pObject->tqmetaObject()->indexOfProperty(szName);
#else
- int idx = m_pObject->metaObject()->findProperty(szName,true);
+ int idx = m_pObject->tqmetaObject()->findProperty(szName,true);
#endif
if(idx < 0)
{
@@ -1164,10 +1164,10 @@ bool KviKvsObject::function_setProperty(KviKvsObjectFunctionCall * c)
return true;
}
#ifdef COMPILE_USE_QT4
- TQMetaProperty prop = m_pObject->metaObject()->property(idx);
+ TQMetaProperty prop = m_pObject->tqmetaObject()->property(idx);
const TQMetaProperty * p = &prop;
#else
- const TQMetaProperty * p = m_pObject->metaObject()->property(idx,true);
+ const TQMetaProperty * p = m_pObject->tqmetaObject()->property(idx,true);
#endif
if(!p)
{
@@ -1385,9 +1385,9 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
}
#ifdef COMPILE_USE_QT4
- int idx = m_pObject->metaObject()->indexOfProperty(szName);
+ int idx = m_pObject->tqmetaObject()->indexOfProperty(szName);
#else
- int idx = m_pObject->metaObject()->findProperty(szName,true);
+ int idx = m_pObject->tqmetaObject()->findProperty(szName,true);
#endif
if(idx < 0)
{
@@ -1400,10 +1400,10 @@ bool KviKvsObject::function_property(KviKvsObjectFunctionCall * c)
return true;
}
#ifdef COMPILE_USE_QT4
- TQMetaProperty prop = m_pObject->metaObject()->property(idx);
+ TQMetaProperty prop = m_pObject->tqmetaObject()->property(idx);
const TQMetaProperty * p = &prop;
#else
- const TQMetaProperty * p = m_pObject->metaObject()->property(idx,true);
+ const TQMetaProperty * p = m_pObject->tqmetaObject()->property(idx,true);
#endif
if(!p)
{
@@ -230,25 +230,25 @@
}
- # Destroy the object and the children
+ # Destroy the object and the tqchildren
[cmd]delete[/cmd] %tmp
[/example]
diff --git a/src/kvirc/kvs/kvi_kvs_script.h b/src/kvirc/kvs/kvi_kvs_script.h
index 60e96a0..2bfd6b8 100644
--- a/src/kvirc/kvs/kvi_kvs_script.h
+++ b/src/kvirc/kvs/kvi_kvs_script.h
@@ -52,7 +52,7 @@ class KVIRC_API KviKvsScript : public KviHeapObject
friend class KviKvsParser;
friend class KviKvsRunTimeContext;
public:
- enum RunStatus {
+ enum RuntqStatus {
// the script returned an error
Error = 0,
// the script ran succesfully
@@ -97,7 +97,7 @@ public:
Quiet = 8
};
// returns 0 (KviKvsScript::RunFailure) on error
// returns a nonzero combination of RunStatus flags on success
int run(KviWindow * pWnd, // window that the command has to be bound to
KviKvsVariantList * pParams = 0, // parameter list (0 if you don't pass params) ownership transferred if PreserverParams is not used
KviKvsVariant * pRetVal = 0, // return value buffer (0 if you ignore it)
@@ -105,7 +105,7 @@ public:
KviKvsExtendedRunTimeData * pExtData = 0); // extended data (usually 0) (if you need to pass extended scope variables or alias switch lists...)
// returns 0 (KviKvsScript::RunFailure) on error
// returns a nonzero combination of RunStatus flags on success
// this is probably used only in /eval
int run(KviKvsRunTimeContext * pContext,int iRunFlags = 0);
@@ -118,12 +118,12 @@ public:
KviKvsExtendedRunTimeData * pExtData = 0);
// static helpers for quick running
// returns a combination of RunStatus flags (nonzero on no error)
// does NOT take params ownership
static int run(const TQString &szCode,KviWindow * pWindow,KviKvsVariantList * pParams = 0,KviKvsVariant * pRetVal = 0);
// static helper for quick evaluating parameters
// returns a combination of RunStatus flags (nonzero on no error)
// does NOT take params ownership
// pRetVal CAN'T be zero here since we're evaluating stuff here
static int evaluate(const TQString &szCode,KviWindow * pWindow,KviKvsVariantList * pParams,KviKvsVariant * pRetVal);
@@ -137,14 +137,14 @@ protected:
bool parse(KviWindow * pOutput = 0,
int iRunFlags = 0);
// returns 0 (KviKvsScript::RunFailure) on error
// returns a nonzero combination of RunStatus flags on success
int execute(KviWindow * pWnd,
KviKvsVariantList * pParams = 0,
KviKvsVariant * pRetVal = 0,
int iRunFlags = 0,
KviKvsExtendedRunTimeData * pExtData = 0);
// returns 0 (KviKvsScript::RunFailure) on error
// returns a nonzero combination of RunStatus flags on success
int executeInternal(KviKvsRunTimeContext * pContext);
const TQChar * buffer() const;
// detaches this script from any other shallow copies
@@ -97,7 +97,7 @@ public:
};
// returns 0 (KviKvsScript::RunFailure) on error
- // returns a nonzero combination of RunStatus flags on success
+ // returns a nonzero combination of RuntqStatus flags on success
int run(KviWindow * pWnd, // window that the command has to be bound to
KviKvsVariantList * pParams = 0, // parameter list (0 if you don't pass params) ownership transferred if PreserverParams is not used
@@ -105,7 +105,7 @@ public:
KviKvsExtendedRunTimeData * pExtData = 0); // extended data (usually 0) (if you need to pass extended scope variables or alias switch lists...)
// returns 0 (KviKvsScript::RunFailure) on error
- // returns a nonzero combination of RunStatus flags on success
+ // returns a nonzero combination of RuntqStatus flags on success
// this is probably used only in /eval
int run(KviKvsRunTimeContext * pContext,int iRunFlags = 0);
@@ -118,12 +118,12 @@ public:
KviKvsExtendedRunTimeData * pExtData = 0);
// static helpers for quick running
- // returns a combination of RunStatus flags (nonzero on no error)
+ // returns a combination of RuntqStatus flags (nonzero on no error)
// does NOT take params ownership
static int run(const TQString &szCode,KviWindow * pWindow,KviKvsVariantList * pParams = 0,KviKvsVariant * pRetVal = 0);
@@ -118,12 +118,12 @@ public:
static int run(const TQString &szCode,KviWindow * pWindow,KviKvsVariantList * pParams = 0,KviKvsVariant * pRetVal = 0);
// static helper for quick evaluating parameters
- // returns a combination of RunStatus flags (nonzero on no error)
+ // returns a combination of RuntqStatus flags (nonzero on no error)
// does NOT take params ownership
// pRetVal CAN'T be zero here since we're evaluating stuff here
@@ -137,14 +137,14 @@ protected:
int iRunFlags = 0);
// returns 0 (KviKvsScript::RunFailure) on error
- // returns a nonzero combination of RunStatus flags on success
+ // returns a nonzero combination of RuntqStatus flags on success
int execute(KviWindow * pWnd,
KviKvsVariantList * pParams = 0,
@@ -137,14 +137,14 @@ protected:
KviKvsExtendedRunTimeData * pExtData = 0);
// returns 0 (KviKvsScript::RunFailure) on error
- // returns a nonzero combination of RunStatus flags on success
+ // returns a nonzero combination of RuntqStatus flags on success
int executeInternal(KviKvsRunTimeContext * pContext);
const TQChar * buffer() const;